@@ -117,7 +117,7 @@ class VariableOsInstallX11Resolution(ResolutionVariable):
     def get(self):
         # get resolution from xorg.log
         res = self.Get('os_x11_resolution')
-        if res or self.Get('os_install_root_type') in ('livecd', 'usb-hdd'):
+        if res or self.Get('install.os_install_root_type') in ('livecd', 'usb-hdd'):
             return res or self.fallback_resolution
         else:
             return self.fallback_resolution
